@@ -50,7 +50,7 @@
  * SECTION:extensionpoints
  * @short_description: Extension Points
  * @include: gio.h
- * @see_also: <link linkend="gio-extension-points">Extending GIO</link>
+ * @see_also: <link linkend="extending-gio">Extending GIO</link>
  *
  * #GIOExtensionPoint provides a mechanism for modules to extend the
  * functionality of the library or application that loaded it in an 
@@ -294,21 +294,20 @@ extern GType _g_local_vfs_get_type (void);
 
 extern GType _g_win32_volume_monitor_get_type (void);
 extern GType g_win32_directory_monitor_get_type (void);
+extern GType _g_winhttp_vfs_get_type (void);
 
 void
-_g_io_modules_ensure_loaded (void)
+_g_io_modules_ensure_extension_points_registered (void)
 {
-  GList *modules, *l;
-  static gboolean loaded_dirs = FALSE;
+  static gboolean registered_extensions = FALSE;
   GIOExtensionPoint *ep;
-  const char *module_path;
 
   G_LOCK (loaded_dirs);
-
-  if (!loaded_dirs)
+  
+  if (!registered_extensions)
     {
-      loaded_dirs = TRUE;
-
+      registered_extensions = TRUE;
+      
 #ifdef G_OS_UNIX
       ep = g_io_extension_point_register (G_DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_DESKTOP_APP_INFO_LOOKUP);
@@ -319,7 +318,7 @@ _g_io_modules_ensure_loaded (void)
       
       ep = g_io_extension_point_register (G_LOCAL_FILE_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_LOCAL_FILE_MONITOR);
-
+      
       ep = g_io_extension_point_register (G_VOLUME_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_VOLUME_MONITOR);
       
@@ -328,7 +327,26 @@ _g_io_modules_ensure_loaded (void)
       
       ep = g_io_extension_point_register (G_VFS_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_VFS);
-      
+    }
+  
+  G_UNLOCK (loaded_dirs);
+ }
+
+void
+_g_io_modules_ensure_loaded (void)
+{
+  GList *modules, *l;
+  static gboolean loaded_dirs = FALSE;
+  const char *module_path;
+
+  _g_io_modules_ensure_extension_points_registered ();
+  
+  G_LOCK (loaded_dirs);
+
+  if (!loaded_dirs)
+    {
+      loaded_dirs = TRUE;
+
       modules = g_io_modules_load_all_in_directory (GIO_MODULE_DIR);
 
       module_path = g_getenv ("GIO_EXTRA_MODULES");
@@ -363,6 +381,9 @@ _g_io_modules_ensure_loaded (void)
 #endif
 #ifdef G_OS_UNIX
       _g_unix_volume_monitor_get_type ();
+#endif
+#ifdef G_OS_WIN32
+      _g_winhttp_vfs_get_type ();
 #endif
       _g_local_vfs_get_type ();
     
@@ -589,7 +610,7 @@ g_io_extension_point_implement (const char *extension_point_name,
       return NULL;
     }      
 
-  /* Its safe to register the same type multiple times */
+  /* It's safe to register the same type multiple times */
   for (l = extension_point->extensions; l != NULL; l = l->next)
     {
       extension = l->data;
