@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 
@@ -1123,16 +1123,18 @@ g_checksum_new (GChecksumType checksum_type)
  * g_checksum_reset:
  * @checksum: the #GChecksum to reset
  *
- * Resets the state of the @checksum back to it's initial state.
+ * Resets the state of the @checksum back to its initial state.
  *
  * Since: 2.18
  **/
 void
 g_checksum_reset (GChecksum *checksum)
 {
+  g_return_if_fail (checksum != NULL);
+
   g_free (checksum->digest_str);
   checksum->digest_str = NULL;
-  
+
   switch (checksum->type)
     {
     case G_CHECKSUM_MD5:
@@ -1387,7 +1389,6 @@ g_compute_checksum_for_data (GChecksumType  checksum_type,
 
   g_return_val_if_fail (IS_VALID_TYPE (checksum_type), NULL);
   g_return_val_if_fail (data != NULL, NULL);
-  g_return_val_if_fail (length > 1, NULL);
 
   checksum = g_checksum_new (checksum_type);
   if (!checksum)
